@@ -335,6 +335,7 @@ class Manager(object):
 		index: str = 'publications',
 		date_start: Optional[str] = None,
 		date_end: Optional[str] = None,
+		fuzziness: bool=False,
 		**kwargs
 	) -> Dict[str, Union[str, Dict[str, int]]]:
 		"""
@@ -363,17 +364,27 @@ class Manager(object):
 				'lte': date_end
 			})
 		]
-		print('***********>', keywords)
 		if len(keywords) > 0:
-			query = Q('bool',
-			  should = [ Q(
+			if fuzziness:
+				_should = [ Q(
 				  'match', **{ field: {
 					  'query': k,
 					  'operator': "and",
 					  'fuzziness': "AUTO:5,8",
 					  'auto_generate_synonyms_phrase_query': False
 				  }}) for k in keywords
-			  ],
+			  	]
+			else:
+				_should = [ Q(
+				  'match', **{ field: {
+					  'query': k,
+					  'operator': "and",
+					  'auto_generate_synonyms_phrase_query': False
+				  }}) for k in keywords
+			  	]
+
+			query = Q('bool',
+			  should = ,
 			  minimum_should_match = 1,
 			  filter = filters)
 			resp = Search(index=index).extra(**extras).query(query).execute()
